flask-resty-tenants |Coverage Status|
=====================================

Authorization for multitenant systems

.. |Coverage Status| image:: https://coveralls.io/repos/github/4Catalyzer/flask-resty-tenants/badge.svg?branch=master
   :target: https://coveralls.io/github/4Catalyzer/flask-resty-tenants?branch=master
